# nagata

[![PyPI Latest Release](https://img.shields.io/pypi/v/nagata.svg?style=for-the-badge&logo=PyPI)](https://pypi.org/project/nagata/)
[![Documentation](https://img.shields.io/badge/docs-mkdocs%20material-blue.svg?style=for-the-badge&logo=github)](https://WithPrecedent.github.io/nagata)
[![GitHub Actions](https://img.shields.io/github/actions/workflow/status/WithPrecedent/nagata/actions?style=for-the-badge&logo=githubactions&logoColor=white)](https://img.shields.io/github/actions/)
![Code Coverage](https://img.shields.io/codecov/c/github/WithPrecedent/nagata?style=for-the-badge&logo=codecov&logoColor=white)
[![PDM Managed](https://img.shields.io/badge/pdm-managed-blueviolet?style=for-the-badge)](https://pdm.fming.dev)
[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg?style=for-the-badge&logo=apache)](https://opensource.org/licenses/Apache-2.0)

## What is nagata?

This readme file offers a basic outline of how `nagata` works. If you would prefer to jump right into the full documentation, go [here](https://WithPrecedent.github.io/nagata).

## Why use nagata?

## Getting started

### Installation

To install `nagata`, use `pip`:

```sh
pip install nagata
```

### Usage

## How does nagata work?

## Contributing

## Similar Projects


## Acknowledgements

[PDM](https://github.com/pdm-project/pdm) and [MkDocs](https://github.com/mkdocs/mkdocs) made my `nagata` development workflow better and easier. I'd also like to extend a special thanks to [pawamoy](https://github.com/pawamoy) whose excellent PDM and Mkdocs extensions and utlities are incorporated into `nagata`. The scripts, documentation, configuration files, and other CI code were all adapted (or simply copied) from pawamoy's repositories.

I would also like to thank the University of Kansas School of Law for tolerating and supporting this law professor's coding efforts, an endeavor which is well outside the typical scholarly activities in the discipline.

